@@ -13,7 +13,9 @@ def tables(ctx):
 @click.pass_context
 def list_tables(ctx):
     click.echo(
-        dataconnect_client.get_tables(ctx.obj["data-connect-url"], get_oauth_token(ctx))
+        dataconnect_client.list_tables(
+            ctx.obj["data-connect-url"], get_oauth_token(ctx)
+        )
     )
 
 
