@@ -11,14 +11,19 @@ class PublisherClient:
         email=None,
         personal_access_token=None,
         dataconnect_url=None,
+        collections_url=None,
         auth_params=auth_params,
     ):
         self.email = email
         self.personal_access_token = personal_access_token
         self.dataconnect_url = dataconnect_url
+        self.collections_url = collections_url
         self.auth_params = auth_params
         self.oauth_token = {}
+        self.dataconnect = self.dataconnect(self)
+        self.collections = self.collections(self)
 
+    """
     def login(self, server=None, email=None, personal_access_token=None):
         # if the user did not provide a PAT or email, get that from input
         if not server:
@@ -41,17 +46,54 @@ class PublisherClient:
             dataconnect_url=self.dataconnect_url,
             drs_url=server,
         )
+    """
 
-    def query(self, q, download=False, use_json=False, raw=False):
-        return json.loads(
-            query(self.dataconnect_url, q, download, use_json, raw, self.oauth_token)
-        )
+    class dataconnect:
+        def __init__(self, parent):
+            self.parent = parent
 
-    def list_tables(self):
-        return json.loads(get_tables(self.dataconnect_url, self.oauth_token))
+        def query(self, q, download=False, use_json=False, raw=False):
+            return json.loads(
+                dataconnect_client.query(
+                    self.parent.dataconnect_url,
+                    q,
+                    download,
+                    use_json,
+                    raw,
+                    self.parent.oauth_token,
+                )
+            )
 
-    def get_table(self, table_name):
-        return json.loads(get_table(self.dataconnect_url, table_name, self.oauth_token))
+        def list_tables(self):
+            return json.loads(
+                dataconnect_client.list_tables(
+                    self.parent.dataconnect_url, self.parent.oauth_token
+                )
+            )
+
+        def get_table(self, table_name):
+            return json.loads(
+                dataconnect_client.get_table(
+                    self.parent.dataconnect_url, table_name, self.parent.oauth_token
+                )
+            )
+
+    class collections:
+        def __init__(self, parent):
+            self.parent = parent
+
+        def list(self):
+            return collections_client.list_collections(self.parent.collections_url)
+
+        def list_tables(self, collection_name):
+            return collections_client.list_tables(
+                self.parent.collections_url, collection_name
+            )
+
+        def query(self, collection_name, query):
+            return collections_client.query(
+                self.parent.collections_url, collection_name, query
+            )
 
     def load(self, urls, output_dir=downloads_directory):
         download_content = []
